@@ -3,6 +3,8 @@ import os
 from sys import path
 from typing import Any, Dict, List
 
+from anyscale import version
+
 
 anyscale_dir = os.path.dirname(os.path.abspath(__file__))
 path.append(os.path.join(anyscale_dir, "client"))
@@ -10,6 +12,7 @@ path.append(os.path.join(anyscale_dir, "sdk"))
 ANYSCALE_RAY_DIR = os.path.join(anyscale_dir, "anyscale_ray")
 
 from anyscale.connect import ClientBuilder  # noqa: E402
+from anyscale.sdk.anyscale_client.sdk import AnyscaleSDK  # noqa: E402
 
 
 # Note: indentation here matches that of connect.py::ClientBuilder.
@@ -37,7 +40,7 @@ for attr, _ in inspect.getmembers(ClientBuilder, inspect.isfunction):
 
     globals()[attr] = _new_builder(attr)
 
-__version__ = "0.3.56"
+__version__ = version.__version__
 
 ANYSCALE_ENV = os.environ.copy()
 ANYSCALE_ENV["PYTHONPATH"] = ANYSCALE_RAY_DIR + ":" + ANYSCALE_ENV.get("PYTHONPATH", "")
