@@ -54,6 +54,7 @@ async def index(request: web.Request) -> web.Response:
         "webterminal": "/webterminal/",
         "anyscaled": "/anyscaled/",
         "metrics": "/metrics",
+        "autoscalermetrics": "/autoscalermetrics",
     }
 
     if not token or not redirect_to or redirect_to not in path.keys():
@@ -104,7 +105,8 @@ async def authorize(request: web.Request) -> web.Response:
                 and token_list[0] == request.config_dict["auth_token"]
             ):
                 return web.Response(text="Authorized", status=200)
-        return web.Response(text="Unauthorized", status=401)
+        unauthorized_message = "Unauthorized. Please navigate to this resource through the cluster's page in the Anyscale product. Doing so will automatically authorize this request."
+        return web.Response(text=unauthorized_message, status=401)
 
 
 def make_auth_proxy_app(auth_token: str) -> web.Application:
