@@ -27,7 +27,7 @@ except ModuleNotFoundError:
 from ray.autoscaler.tags import TAG_RAY_CLUSTER_NAME, TAG_RAY_NODE_NAME
 
 from anyscale.autoscaler.node_provided_cache import NodeProviderCache
-import anyscale.conf
+import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
 
 
 logger = logging.getLogger(__name__)
@@ -86,7 +86,7 @@ class AnyscaleAWSNodeProvider(AWSNodeProvider):  # type: ignore
         with outdated tags, and total throughput across many node providers can be centrally
         throttled.
         """
-        node_tags[TAG_ANYSCALE_HOST] = anyscale.conf.ANYSCALE_HOST
+        node_tags[TAG_ANYSCALE_HOST] = shared_anyscale_conf.ANYSCALE_HOST
 
         for k, v in node_tags.items():
             m = "Set tag {}={} on {}".format(k, v, node_id)
