@@ -1,18 +1,25 @@
 """NodeProvider classes that add product-specific behaviour."""
 
+import base64
 import copy
 import inspect
+import json
 import logging
 import time
 from types import ModuleType
 from typing import Any, cast, Dict, List, Optional
 
 from openapi_client.rest import ApiException
+from ray import cloudpickle
 from ray.autoscaler._private.aws.node_provider import to_aws_format
 from ray.autoscaler._private.command_runner import DockerCommandRunner, SSHCommandRunner
 from ray.autoscaler._private.util import hash_launch_conf
 from ray.autoscaler.command_runner import CommandRunnerInterface
-from ray.autoscaler.tags import TAG_RAY_CLUSTER_NAME
+from ray.autoscaler.tags import (
+    STATUS_UP_TO_DATE,
+    TAG_RAY_CLUSTER_NAME,
+    TAG_RAY_NODE_STATUS,
+)
 from urllib3.exceptions import HTTPError  # type: ignore
 import wrapt
 
@@ -52,7 +59,7 @@ from anyscale.client.openapi_client.models.set_node_tags_options import (
 from anyscale.client.openapi_client.models.wait_until_stopped_options import (
     WaitUntilStoppedOptions,
 )
-from anyscale.util import format_api_exception, get_autoscaler_container_path
+from anyscale.shared_anyscale_utils.util import get_autoscaler_container_path
 
 
 logger = logging.getLogger(__name__)
@@ -221,7 +228,32 @@ class AnyscaleInstanceManagerNodeProvider:
             tags=tags,
             count=count,
         )
-        self.api_client.create_nodes_api_v2_instances_post(create_node_request)
+        # Catch, process, and repropagate remote exceptions.
+        remote_exc = None
+        try:
+            self.api_client.create_nodes_api_v2_instances_post(create_node_request)
+        except ApiException as api_exception:
+            try:
+                error_detail = json.loads(api_exception.body)
+                ser_exc = error_detail["error"]["detail"]
+                remote_exc = cloudpickle.loads(base64.b64decode(ser_exc))
+            except Exception as deserialization_error:
+                logger.warn(
+                    "create_node() received an ApiException, "
+                    "but we were unable to deserialize it "
+                    f"({deserialization_error}). "
+                    "Raising the ApiException unchanged."
+                )
+                raise api_exception
+
+        # Raise the unwrapped error away from the try/except clause
+        # so the ApiException codegenned frames do not tag along.
+        if remote_exc:
+            logger.warn(
+                "create_node() received an ApiException. "
+                "Unwrapping and raising the original remote exception instead."
+            )
+            raise remote_exc
 
     def set_node_tags(self, node_id: str, tags: Dict[str, str]) -> None:
         if not self.is_provider_supported:
@@ -317,6 +349,9 @@ class AnyscaleInstanceManagerNodeProvider:
             resp = self.api_client.get_node_id_by_external_ip_api_v2_instances_external_ip_get_node_id_by_external_ip_get(
                 ip_address
             )
+
+        if not resp.result.instance_id:
+            raise ValueError("IP {ip_address} not found.")
         return cast(str, resp.result.instance_id)
 
     def get_command_runner(
@@ -430,7 +465,7 @@ class AnyscalePoolingNodeProvider(AnyscaleInstanceManagerNodeProvider):
         # Pooling version (with checks).
         if not (bypass_rapid_start or pool_disabled):
             if self._is_aws_provider():
-                for i in range(count):
+                for _ in range(count):
                     self._create_single_node_aws(node_config, tags)
                 return
 
@@ -528,10 +563,9 @@ class AnyscalePoolingNodeProvider(AnyscaleInstanceManagerNodeProvider):
             cloud_id=self.cloud_id,
             instance_reuse_id=instance_reuse_id,
         )
-        with format_api_exception(ApiException):
-            self.api_client.add_instance_to_pool_api_v2_instancepools_add_instance_post(
-                instance_pool_submission
-            )
+        self.api_client.add_instance_to_pool_api_v2_instancepools_add_instance_post(
+            instance_pool_submission
+        )
 
     def _prepare_node_for_idempotent_reuse(self, node_id: str) -> None:
         """Does necessary resets on node to prepare it for reuse."""
@@ -541,7 +575,6 @@ class AnyscalePoolingNodeProvider(AnyscaleInstanceManagerNodeProvider):
         # which should ideally be garbage collected (TODO (xcl)),
         # but this is not a high priority because we may also just
         # expire sessions in the pool after they've been reused a lot.
-        pass
 
     def terminate_nodes(self, node_ids: List[str]) -> None:
         # TODO(xcl): add support for non-aws instances.
@@ -573,10 +606,7 @@ class AnyscalePoolingNodeProvider(AnyscaleInstanceManagerNodeProvider):
     def _pool_size(self) -> int:
         """Get this cloud's current pool size."""
         query = QueryPoolSize(cloud_id=self.cloud_id)
-        with format_api_exception(ApiException):
-            pool_size = self.api_client.pool_size_api_v2_instancepools_pool_size_post(
-                query
-            )
+        pool_size = self.api_client.pool_size_api_v2_instancepools_pool_size_post(query)
         return int(pool_size)
 
     def _pool_limit(self) -> int:
@@ -607,3 +637,7 @@ class AnyscaleExecNodeProvider(NodeProvider):  # type: ignore
 
     def external_ip(self, node_id: str) -> str:
         return node_id
+
+    def node_tags(self, node_id: str) -> Dict[str, Any]:
+        # Necessary because Ray requires that head node to have this tag set.
+        return {TAG_RAY_NODE_STATUS: STATUS_UP_TO_DATE}
