@@ -4,7 +4,6 @@ from click import ClickException
 from openapi_client.rest import ApiException
 
 from anyscale.client.openapi_client.api.default_api import DefaultApi
-from anyscale.util import format_api_exception
 
 
 def get_cloud_json_from_id(cloud_id: str, api_client: DefaultApi) -> Dict["str", Any]:
@@ -39,29 +38,28 @@ def get_cloud_id_and_name(
             "Both '--cloud-id' and '--cloud-name' specified. Please only use one."
         )
     elif cloud_name:
-        with format_api_exception(ApiException):
-            resp_get_cloud = api_client.find_cloud_by_name_api_v2_clouds_find_by_name_post(
-                cloud_name_options={"name": cloud_name}
-            )
+        resp_get_cloud = api_client.find_cloud_by_name_api_v2_clouds_find_by_name_post(
+            cloud_name_options={"name": cloud_name}
+        )
         cloud = resp_get_cloud.result
     elif cloud_id:
-        with format_api_exception(ApiException):
-            resp_get_cloud = api_client.get_cloud_api_v2_clouds_cloud_id_get(
-                cloud_id=cloud_id
-            )
+        resp_get_cloud = api_client.get_cloud_api_v2_clouds_cloud_id_get(
+            cloud_id=cloud_id
+        )
 
         cloud = resp_get_cloud.result
     else:
         try:
             clouds = api_client.list_clouds_api_v2_clouds_get().results
-        except ApiException as e:
-            if e.status == 404:
+        except Exception as e:
+            if (isinstance(e, ApiException) and e.status == 404) or (  # type: ignore
+                isinstance(e, ClickException) and "Reason: 404" in str(e)
+            ):
                 # No clouds
                 raise ClickException(
                     'There are no clouds assigned to your account. Please create a cloud using "anyscale cloud setup".'
                 )
-            with format_api_exception(ApiException):
-                raise e
+            raise e
 
         if len(clouds) > 1:
             raise ClickException(
