@@ -32,7 +32,7 @@ def anyscale_clone(project_name: str, owner: Optional[str]) -> None:
 @click.option("--name", help="Project name.", required=False)
 @click.option(
     "--config",
-    help="Path to autoscaler yaml. Created by default.",
+    help="[DEPRECATED] Path to autoscaler yaml. Created by default.",
     type=click.Path(exists=True),
     required=False,
 )
