@@ -7,8 +7,9 @@ import click
 
 from anyscale.auth_proxy import make_auth_proxy_app
 from anyscale.project import get_project_id, get_project_session, load_project_or_throw
+from anyscale.shared_anyscale_utils.util import execution_log_name
 from anyscale.snapshot import copy_file
-from anyscale.util import deserialize_datetime, execution_log_name, send_json_request
+from anyscale.util import deserialize_datetime, send_json_request
 
 
 logger = logging.getLogger(__file__)
