@@ -8,29 +8,32 @@ from typing import Optional
 
 import boto3
 from click import ClickException
-from openapi_client.rest import ApiException
 
 from anyscale.api import get_api_client
+from anyscale.cli_logger import _CliLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.client.openapi_client.models.cloud_config import CloudConfig
 from anyscale.client.openapi_client.models.write_cloud import WriteCloud
 from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
 import anyscale.conf
 from anyscale.util import (
+    _CACHED_GCP_REGIONS,
     _get_role,
     _resource,
     confirm,
-    format_api_exception,
     get_available_regions,
     launch_gcp_cloud_setup,
 )
 
 
 class CloudController(object):
-    def __init__(self, api_client: DefaultApi = None):
+    def __init__(
+        self, api_client: DefaultApi = None, log: _CliLogger = _CliLogger(),
+    ):
         if api_client is None:
             api_client = get_api_client()
         self.api_client = api_client
+        self.log = log
 
     def delete_cloud(
         self,
@@ -54,12 +57,9 @@ class CloudController(object):
             skip_confirmation,
         )
 
-        with format_api_exception(ApiException):
-            self.api_client.delete_cloud_api_v2_clouds_cloud_id_delete(
-                cloud_id=cloud_id
-            )
+        self.api_client.delete_cloud_api_v2_clouds_cloud_id_delete(cloud_id=cloud_id)
 
-        print(f"Deleted cloud {cloud_name}")
+        self.log.info(f"Deleted cloud {cloud_name}")
 
         return True
 
@@ -79,7 +79,17 @@ class CloudController(object):
             # If the region is blank, change it to the default for GCP.
             if region is None:
                 region = "us-west1"
-            # TODO: interactive setup process through the CLI?
+            # Warn the user about a bad region before the cloud configuration begins.
+            # GCP's `list regions` API requires a project, meaning true verification
+            # happens in the middle of the flow.
+            if region not in _CACHED_GCP_REGIONS:
+                confirm(
+                    f"You selected the region: {region}, but it is not in"
+                    f"the cached list of GCP regions:\n\n{_CACHED_GCP_REGIONS}.\n"
+                    "Continue cloud setup with this region?",
+                    False,
+                )
+                # warn here
             launch_gcp_cloud_setup(name=name, region=region)
         else:
             raise ClickException(
@@ -102,25 +112,25 @@ class CloudController(object):
             yes,
         )
 
-        with format_api_exception(ApiException):
-            user_info = self.api_client.get_user_info_api_v2_userinfo_get().result
+        user_info = self.api_client.get_user_info_api_v2_userinfo_get().result
 
         self.setup_aws_cross_account_role(region, user_info.id, name)
         self.setup_aws_ray_role(region, DEFAULT_RAY_IAM_ROLE)
 
-        print("AWS credentials setup complete!")
-        print(
+        self.log.info("AWS credentials setup complete!")
+        self.log.info(
             "You can revoke the access at any time by deleting anyscale IAM user/role in your account."
         )
-        print("Head over to the web UI to create new sessions in your AWS account!")
+        self.log.info(
+            "Head over to the web UI to create new sessions in your AWS account!"
+        )
 
     def setup_aws_cross_account_role(
         self, region: str, user_id: str, name: str
     ) -> None:
-        with format_api_exception(ApiException):
-            response = (
-                self.api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get()
-            )
+        response = (
+            self.api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get()
+        )
 
         anyscale_aws_account = response.result.anyscale_aws_account
         anyscale_aws_iam_role_policy = {
@@ -148,18 +158,17 @@ class CloudController(object):
         role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/AmazonEC2FullAccess")
         role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/IAMFullAccess")
 
-        print(f"Using IAM role {role.arn}")
+        self.log.info(f"Using IAM role {role.arn}")
 
-        with format_api_exception(ApiException):
-            self.api_client.create_cloud_api_v2_clouds_post(
-                write_cloud=WriteCloud(
-                    provider="AWS",
-                    region=region,
-                    credentials=role.arn,
-                    creator_id=user_id,
-                    name=name,
-                )
+        self.api_client.create_cloud_api_v2_clouds_post(
+            write_cloud=WriteCloud(
+                provider="AWS",
+                region=region,
+                credentials=role.arn,
+                creator_id=user_id,
+                name=name,
             )
+        )
 
     def setup_aws_ray_role(self, region: str, role_name: str) -> None:
         iam = boto3.resource("iam", region_name=region)
@@ -221,14 +230,13 @@ class CloudController(object):
             self.api_client, cloud_id, cloud_name
         )
 
-        with format_api_exception(ApiException):
-            self.api_client.update_cloud_config_api_v2_clouds_cloud_id_config_put(
-                cloud_id=cloud_id,
-                cloud_config=CloudConfig(max_stopped_instances=max_stopped_instances),
-            )
+        self.api_client.update_cloud_config_api_v2_clouds_cloud_id_config_put(
+            cloud_id=cloud_id,
+            cloud_config=CloudConfig(max_stopped_instances=max_stopped_instances),
+        )
 
-        print(f"Updated config for cloud '{cloud_name}' to:")
-        print(self.get_cloud_config(cloud_name=None, cloud_id=cloud_id))
+        self.log.info(f"Updated config for cloud '{cloud_name}' to:")
+        self.log.info(self.get_cloud_config(cloud_name=None, cloud_id=cloud_id))
 
     def get_cloud_config(
         self, cloud_name: Optional[str] = None, cloud_id: Optional[str] = None,
@@ -260,9 +268,8 @@ class CloudController(object):
             self.api_client, cloud_id, cloud_name
         )
 
-        with format_api_exception(ApiException):
-            self.api_client.update_default_cloud_api_v2_organizations_update_default_cloud_post(
-                cloud_id=cloud_id
-            )
+        self.api_client.update_default_cloud_api_v2_organizations_update_default_cloud_post(
+            cloud_id=cloud_id
+        )
 
-        print(f"Updated default cloud to {cloud_name}")
+        self.log.info(f"Updated default cloud to {cloud_name}")
