@@ -7,15 +7,17 @@ from typing import Any, List, Tuple
 
 import click
 
+import anyscale
 from anyscale.api import get_api_client
+from anyscale.cli_logger import _CliLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.client.openapi_client.models.execute_interactive_command_options import (
     ExecuteInteractiveCommandOptions,
 )
 from anyscale.cluster_config import get_cluster_config
-import anyscale.conf
 from anyscale.project import get_project_id, get_project_session, load_project_or_throw
-from anyscale.util import execution_log_name
+import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
+from anyscale.shared_anyscale_utils.util import execution_log_name
 
 
 from anyscale.cluster_config import (  # noqa: N812 isort: skip
@@ -30,10 +32,13 @@ def rsync(*args: Any, **kwargs: Any) -> None:
 
 
 class ExecController(object):
-    def __init__(self, api_client: DefaultApi = None):
+    def __init__(
+        self, api_client: DefaultApi = None, log: _CliLogger = _CliLogger(),
+    ):
         if api_client is None:
             api_client = get_api_client()
         self.api_client = api_client
+        self.log = log
 
     def anyscale_exec(
         self,
@@ -46,6 +51,12 @@ class ExecController(object):
         terminate: bool,
         commands: List[str],
     ) -> None:
+        message = (
+            "Warning: `anyscale exec` is not recommended for sessions started with "
+            "ray.client().connect(). Please call your script from a subprocess call in a remote "
+            "function for ray.client().connect() sessions."
+        )
+        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
         import ray.scripts.scripts as autoscaler_scripts
 
         if screen and tmux:
@@ -127,7 +138,7 @@ class ExecController(object):
         if tmux or screen:
             launched_in_mode = "tmux" if tmux else "screen"
             run_cmd = "tmux attach" if tmux else "screen -xRR"
-            click.echo(
+            self.log.info(
                 "Command launched in {mode}, log into the cluster using `anyscale ssh {name}` and run `{run_cmd}` to check on the status.".format(
                     mode=launched_in_mode, name=session_name, run_cmd=run_cmd
                 )
@@ -154,7 +165,7 @@ class ExecController(object):
             "export ANYSCALE_HOST={anyscale_host}; "
             "export ANYSCALE_SESSION_COMMAND_ID={session_command_id}; ".format(
                 execution_log_name=execution_log_name(session_command_id),
-                anyscale_host=anyscale.conf.ANYSCALE_HOST,
+                anyscale_host=shared_anyscale_conf.ANYSCALE_HOST,
                 session_command_id=session_command_id,
             )
         )
@@ -176,7 +187,7 @@ class ExecController(object):
             "finish_command --command-id {session_command_id} {stop_cmd} {terminate_cmd} {redirect_to_dev_null}; ".format(
                 directory_name=directory_name,
                 execution_log_name=(execution_log_name(session_command_id)),
-                anyscale_host=anyscale.conf.ANYSCALE_HOST,
+                anyscale_host=shared_anyscale_conf.ANYSCALE_HOST,
                 session_command_id=session_command_id,
                 stop_cmd="--stop" if stop else "",
                 terminate_cmd="--terminate" if terminate else "",
