@@ -3,26 +3,21 @@ import os
 from typing import Optional
 
 import click
-from openapi_client.rest import ApiException
 
 import anyscale
 from anyscale.api import get_anyscale_api_client, get_api_client
+from anyscale.cli_logger import _CliLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.cloud import get_cloud_id_and_name
 from anyscale.project import (
-    clone_cluster_config,
+    _write_project_file_to_disk,
     create_new_proj_def,
     get_proj_id_from_name,
     load_project_or_throw,
     register_project,
 )
 from anyscale.sdk.anyscale_client.api.default_api import DefaultApi as AnyscaleApi
-from anyscale.util import (
-    format_api_exception,
-    get_endpoint,
-    get_project_directory_name,
-    validate_cluster_configuration,
-)
+from anyscale.util import get_endpoint
 
 
 COMPUTE_CONFIG_FILENAME = "example_compute_config.json"
@@ -33,6 +28,7 @@ class ProjectController:
         self,
         api_client: Optional[DefaultApi] = None,
         anyscale_client: Optional[AnyscaleApi] = None,
+        log: _CliLogger = _CliLogger(),
     ):
         if api_client is None:
             api_client = get_api_client()
@@ -41,12 +37,13 @@ class ProjectController:
         if anyscale_client is None:
             anyscale_client = get_anyscale_api_client()
         self.anyscale_api_client = anyscale_client
+        self.log = log
 
     def clone(self, project_name: str, owner: Optional[str] = None) -> None:
         project_id = get_proj_id_from_name(project_name, self.api_client, owner)
 
         os.makedirs(project_name)
-        clone_cluster_config(project_name, project_name, project_id, self.api_client)
+        _write_project_file_to_disk(project_id, project_name)
 
         self._write_sample_compute_config(
             filepath=os.path.join(project_name, COMPUTE_CONFIG_FILENAME),
@@ -59,9 +56,14 @@ class ProjectController:
         config: Optional[str] = None,
         requirements: Optional[str] = None,
     ) -> None:
-        project_id_path = anyscale.project.ANYSCALE_PROJECT_FILE
         if config:
-            validate_cluster_configuration(config, api_instance=self.api_client)
+            message = (
+                "Warning: `anyscale init` is no longer accepting a cluster yaml in "
+                "the --config argument. All sessions should be started with cluster envs "
+                "and cluster computes."
+            )
+            self.log.warning(message)
+        project_id_path = anyscale.project.ANYSCALE_PROJECT_FILE
 
         if os.path.exists(project_id_path):
             # Project id exists.
@@ -69,63 +71,30 @@ class ProjectController:
             project_id = project_definition.config["project_id"]
 
             # Checking if the project is already registered.
-            with format_api_exception(ApiException):
-                # TODO: Fetch project by id rather than listing all projects
-                resp = self.api_client.list_projects_api_v2_projects_get()
+            # TODO: Fetch project by id rather than listing all projects
+            resp = self.api_client.list_projects_api_v2_projects_get()
             for project in resp.results:
                 if project.id == project_id:
-                    if not os.path.exists(anyscale.project.ANYSCALE_AUTOSCALER_FILE):
-                        # Session yaml file doesn't exist.
-                        project_name = get_project_directory_name(
-                            project.id, self.api_client
-                        )
-                        url = get_endpoint(f"/projects/{project.id}")
-                        if click.confirm(
-                            "Session configuration missing in local project. Would "
-                            "you like to replace your local copy of {project_name} "
-                            "with the version in Anyscale ({url})?".format(
-                                project_name=project_name, url=url
-                            )
-                        ):
-                            clone_cluster_config(
-                                project_name, os.getcwd(), project.id, self.api_client
-                            )
-                            print(f"Created project {project.id}. View at {url}")
-                            return
-                    else:
-                        raise click.ClickException(
-                            "This project is already created at {url}.".format(
-                                url=get_endpoint(f"/projects/{project.id}")
-                            )
+                    raise click.ClickException(
+                        "This project is already created at {url}".format(
+                            url=get_endpoint(f"/projects/{project.id}")
                         )
+                    )
             # Project id exists locally but not registered in the db.
             if click.confirm(
                 "The Anyscale project associated with this doesn't "
-                "seem to exist anymore. Do you want to re-create it?",
+                "seem to exist anymore or is not valid. Do you want "
+                "to re-create it?",
                 abort=True,
             ):
                 os.remove(project_id_path)
-                if os.path.exists(anyscale.project.ANYSCALE_AUTOSCALER_FILE):
-                    project_name, project_definition = create_new_proj_def(
-                        name,
-                        project_definition.cluster_yaml(),
-                        use_default_yaml=False,
-                        api_client=self.api_client,
-                    )
-                else:
-                    project_name, project_definition = create_new_proj_def(
-                        name,
-                        config,
-                        use_default_yaml=(not bool(config)),
-                        api_client=self.api_client,
-                    )
+                _, project_definition = create_new_proj_def(
+                    name, api_client=self.api_client,
+                )
         else:
             # Project id doesn't exist and not enough info to create project.
-            project_name, project_definition = create_new_proj_def(
-                name,
-                config,
-                use_default_yaml=(not bool(config)),
-                api_client=self.api_client,
+            _, project_definition = create_new_proj_def(
+                name, api_client=self.api_client,
             )
 
         register_project(project_definition, self.api_client)
