@@ -6,7 +6,6 @@ import sys
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 import click
-from openapi_client.rest import ApiException
 import yaml
 
 from anyscale.api import get_anyscale_api_client, get_api_client
@@ -16,6 +15,7 @@ from anyscale.autosync_heartbeat import (
     perform_autopush_synchronization,
     perform_sync,
 )
+from anyscale.cli_logger import _CliLogger
 from anyscale.client.openapi_client import (
     AppConfig,
     Build,
@@ -46,14 +46,12 @@ from anyscale.sdk.anyscale_client import (
     StartSessionOptions,
     UpdateSession,
 )
+from anyscale.shared_anyscale_utils.util import get_container_name, slugify
 from anyscale.util import (
     canonicalize_remote_location,
-    format_api_exception,
-    get_container_name,
     get_endpoint,
     get_working_dir,
     populate_session_args,
-    slugify,
     validate_cluster_configuration,
     wait_for_head_node_start,
     wait_for_session_start,
@@ -81,6 +79,7 @@ class SessionController:
         self,
         api_client: Optional[DefaultApi] = None,
         anyscale_api_client: Optional[DefaultApi] = None,
+        log: _CliLogger = _CliLogger(),
     ):
         if api_client is None:
             api_client = get_api_client()
@@ -88,6 +87,7 @@ class SessionController:
             anyscale_api_client = get_anyscale_api_client()
         self.api_client = api_client
         self.anyscale_api_client = anyscale_api_client
+        self.log = log
 
     def stop(
         self,
@@ -127,7 +127,9 @@ class SessionController:
         session_names = [session.name for session in sessions]
         session_names_str = ", ".join(session_names)
         url = get_endpoint(f"/projects/{project_id}")
-        print(f"Session {session_names_str} shutting down. View progress at {url}")
+        self.log.info(
+            f"Session {session_names_str} shutting down. View progress at {url}"
+        )
 
     def start(
         self,
@@ -145,10 +147,10 @@ class SessionController:
             )
         message = (
             "Warning: `anyscale start` has been deprecated. Please try "
-            "using `anyscale.connect()` for your use case and let the Anyscale team "
+            "using `ray.client().connect()` for your use case and let the Anyscale team "
             "know if you are having any issues."
         )
-        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
+        self.log.warning(message)
 
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
@@ -197,6 +199,14 @@ class SessionController:
         no_rapid_start: bool = False,
         dangerously_set_build_id: Optional[str] = None,
     ) -> None:
+        message = (
+            "Warning: `anyscale up` is now deprecated in favor of ray.client().connect(). "
+            "`anyscale up` will still work for the time being, but we will remove it around "
+            "the end of Q3. Please refer to https://docs.anyscale.com/api-sdk-reference/anyscale-ray-client "
+            "to learn more about using ray.client().connect() and let the Anyscale team know if you "
+            "are running into any issues."
+        )
+        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
         # TODO(ilr) Split this into ~3 functions, look at jbai's comments on #1469
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
@@ -304,28 +314,27 @@ class SessionController:
             compute_template_id = created_template.id
 
         try:
-            with format_api_exception(ApiException):
-                up_response = self.api_client.start_empty_session_api_v2_sessions_start_empty_session_post(
-                    session_up_options=SessionUpOptions(
-                        project_id=project_id,
-                        name=session_name,
-                        cluster_config={"config": json.dumps(cluster_config)}
-                        if cluster_config
-                        else None,
-                        build_id=build_id,
-                        compute_template_id=compute_template_id,
-                        cloud_id=cloud_id,
-                        idle_timeout=idle_timeout,
-                        restart_only=restart_only,
-                        no_restart=no_restart,
-                        start_empty_head_node_only=start_empty_head_node_only,
-                        dangerously_set_build_id=dangerously_set_build_id,
-                    )
-                ).result
+            up_response = self.api_client.start_empty_session_api_v2_sessions_start_empty_session_post(
+                session_up_options=SessionUpOptions(
+                    project_id=project_id,
+                    name=session_name,
+                    cluster_config={"config": json.dumps(cluster_config)}
+                    if cluster_config
+                    else None,
+                    build_id=build_id,
+                    compute_template_id=compute_template_id,
+                    cloud_id=cloud_id,
+                    idle_timeout=idle_timeout,
+                    restart_only=restart_only,
+                    no_restart=no_restart,
+                    start_empty_head_node_only=start_empty_head_node_only,
+                    dangerously_set_build_id=dangerously_set_build_id,
+                )
+            ).result
             session_id = up_response.session_id
             second_update_required = up_response.second_update_required
             wait_for_head_node_start(
-                project_id, session_name, session_id, self.api_client
+                project_id, session_name, session_id, self.api_client  # type: ignore
             )
 
             try:
@@ -346,21 +355,20 @@ class SessionController:
                     "{}\nSession startup failed while transferring files".format(e)
                 )
 
-            with format_api_exception(ApiException):
-                self.api_client.setup_and_initialize_session_api_v2_sessions_session_id_setup_and_initialize_session_post(
-                    session_id=session_id,
-                    setup_initialize_session_options=SetupInitializeSessionOptions(
-                        project_id=project_id,
-                        cluster_config={"config": json.dumps(cluster_config)},
-                        restart_only=restart_only,
-                        no_restart=no_restart,
-                        no_update=not second_update_required,
-                    ),
-                )
+            self.api_client.setup_and_initialize_session_api_v2_sessions_session_id_setup_and_initialize_session_post(
+                session_id=session_id,
+                setup_initialize_session_options=SetupInitializeSessionOptions(
+                    project_id=project_id,
+                    cluster_config={"config": json.dumps(cluster_config)},
+                    restart_only=restart_only,
+                    no_restart=no_restart,
+                    no_update=not second_update_required,
+                ),
+            )
 
-            wait_for_session_start(project_id, session_name, self.api_client)
+            wait_for_session_start(project_id, session_name, self.api_client)  # type: ignore
             url = get_endpoint(f"/projects/{project_id}/sessions/{session_id}")
-            print(f"Session {session_name} started. View at {url}")
+            self.log.info(f"Session {session_name} started. View at {url}")
         except KeyboardInterrupt:
             self.api_client.stop_session_api_v2_sessions_session_id_stop_post(
                 session_id,
@@ -384,16 +392,16 @@ class SessionController:
     ) -> str:
         source_session = self._resolve_session(session_name, project_name)
         if source_session.state == SessionState.RUNNING:
-            print(
+            self.log.warning(
                 "WARNING: Session is currently running, this may take several minutes."
             )
 
         project_url = get_endpoint(f"/projects/{source_session.project_id}")
-        print(
+        self.log.info(
             f"Forking session {session_name} into {new_session_name}. You can view its progress at {project_url}"
         )
         cloned_session = self._fork_session_internal(source_session, new_session_name)
-        print(f"Session {session_name} forked.")
+        self.log.info(f"Session {session_name} forked.")
 
         wait_for_session_start(
             cloned_session.project_id, cloned_session.name, self.api_client
@@ -412,10 +420,9 @@ class SessionController:
             session_name, self.api_client, disable_project_sync=True
         )
 
-        with format_api_exception(ApiException):
-            head_ip = self.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get(
-                session.id
-            ).result.head_ip
+        head_ip = self.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get(
+            session.id
+        ).result.head_ip
 
         ssh_user = cluster_config["auth"]["ssh_user"]
         key_path = cluster_config["auth"]["ssh_private_key"]
@@ -442,6 +449,17 @@ class SessionController:
         delete: bool = False,
         ignore_errors: bool = False,
     ) -> None:
+        message = (
+            "Warning: `anyscale autopush` is now deprecated as we encourage users to start "
+            "clusters with ray.client().connect() and runtime environments. "
+            "`anyscale autopush` will still work for the time being for clusters started "
+            "with the sdk, but we will remove it around the end of Q3. Please refer to "
+            "https://docs.anyscale.com/api-sdk-reference/anyscale-ray-client "
+            "to learn more about using ray.client().connect() and let the Anyscale team know if you "
+            "are running into any issues."
+        )
+        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
+
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
         print(f"Active project: {project_definition.root}\n")
@@ -455,10 +473,9 @@ class SessionController:
         rsync_exclude = cluster_config.get("rsync_exclude") or []
         rsync_filter = cluster_config.get("rsync_filter") or []
 
-        with format_api_exception(ApiException):
-            head_ip = self.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get(
-                session.id
-            ).result.head_ip
+        head_ip = self.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get(
+            session.id
+        ).result.head_ip
         ssh_user = cluster_config["auth"]["ssh_user"]
         ssh_private_key_path = cluster_config["auth"]["ssh_private_key"]
 
@@ -531,7 +548,7 @@ class SessionController:
         project_definition = load_project_or_throw()
 
         try:
-            print("Collecting files from remote.")
+            self.log.info("Collecting files from remote.")
             project_id = get_project_id(project_definition.root)
             cluster_config = get_cluster_config(session_name, self.api_client)
             directory_name = get_working_dir(
@@ -547,6 +564,7 @@ class SessionController:
 
             with set_env(**aws_credentials):
                 if source and target:
+                    target = os.path.expanduser(target)
                     rsync(
                         cluster_config, source=source, target=target, down=True,
                     )
@@ -564,23 +582,22 @@ class SessionController:
 
             if config:
                 session = get_project_session(project_id, session_name, self.api_client)
-                with format_api_exception(ApiException):
-                    resp = self.api_client.get_session_cluster_config_api_v2_sessions_session_id_cluster_config_get(
-                        session.id
-                    )
+                resp = self.api_client.get_session_cluster_config_api_v2_sessions_session_id_cluster_config_get(
+                    session.id
+                )
                 cluster_config = yaml.safe_load(resp.result.config_with_defaults)
                 with open(config, "w") as f:
                     yaml.dump(cluster_config, f, default_flow_style=False)
 
-            print("Pull completed.")
+            self.log.info("Pull completed.")
 
         except Exception as e:
             print(e)
-            raise click.ClickException(e)  # type: ignore
+            raise click.ClickException(str(e))  # type: ignore
 
     def push(
         self,
-        session_name: str,
+        session_name: Optional[str],
         source: Optional[str],
         target: Optional[str],
         config: Optional[str],
@@ -602,7 +619,7 @@ class SessionController:
                 "--source any --target arguments). Please let the Anyscale team know if "
                 "this will block your use case."
             )
-            print("\033[91m{}\033[00m".format(message), file=sys.stderr)
+            self.log.warning(message)
 
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
@@ -632,7 +649,7 @@ class SessionController:
 
         if config:
             validate_cluster_configuration(config, api_instance=self.api_client)
-            print("Updating session with {}".format(config))
+            self.log.info("Updating session with {}".format(config))
             self.up(
                 session_name=session_name,
                 config=None,
@@ -648,7 +665,7 @@ class SessionController:
                 idle_timeout=None,
             )
         url = get_endpoint(f"/projects/{project_id}/sessions/{session.id}")
-        print(f"Pushed to session {session_name}. View at {url}")
+        self.log.info(f"Pushed to session {session_name}. View at {url}")
 
     # Helpers
 
@@ -670,6 +687,7 @@ class SessionController:
             )
         else:
             session_name = slugify(session_name)
+        assert session_name
         return session_name
 
     def _register_compute_config(
@@ -797,7 +815,7 @@ class SessionController:
         has_more = True
         while has_more:
             resp = self.anyscale_api_client.list_app_configs(
-                project_id, count=50, paging_token=None
+                project_id=project_id, count=50, paging_token=None
             )
             entities.extend(resp.results)
             paging_token = resp.metadata.next_paging_token
@@ -833,8 +851,7 @@ class SessionController:
                        if absent, we use the workspace's project
         """
         if project_name:
-            with format_api_exception(ApiException):
-                projects = self.api_client.list_projects_api_v2_projects_get().results
+            projects = self.api_client.list_projects_api_v2_projects_get().results
             project = next(
                 project for project in projects if project.name == project_name
             )
@@ -843,10 +860,9 @@ class SessionController:
             project_definition = load_project_or_throw()
             project_id = get_project_id(project_definition.root)
 
-        with format_api_exception(ApiException):
-            sessions_list = self.api_client.list_sessions_api_v2_sessions_get(
-                project_id, name=session_name
-            ).results
+        sessions_list = self.api_client.list_sessions_api_v2_sessions_get(
+            project_id, name=session_name
+        ).results
 
         if len(sessions_list) == 0:
             raise click.ClickException(
@@ -866,20 +882,18 @@ class SessionController:
         source_session - session to clone
         new_session_name - name of the new session
         """
-        with format_api_exception(ApiException):
-            self.api_client.fork_session_api_v2_sessions_session_id_fork_post(
-                session_id=source_session.id,
-                create_session_from_snapshot_options=CreateSessionFromSnapshotOptions(
-                    project_id=source_session.project_id, name=new_session_name
-                ),
-                # forking an active session can take up to 180s
-                _request_timeout=300000,
-            )
-
-        with format_api_exception(ApiException):
-            forked_sessions_list = self.api_client.list_sessions_api_v2_sessions_get(
+        self.api_client.fork_session_api_v2_sessions_session_id_fork_post(
+            session_id=source_session.id,
+            create_session_from_snapshot_options=CreateSessionFromSnapshotOptions(
                 project_id=source_session.project_id, name=new_session_name
-            ).results
+            ),
+            # forking an active session can take up to 180s
+            _request_timeout=300000,
+        )
+
+        forked_sessions_list = self.api_client.list_sessions_api_v2_sessions_get(
+            project_id=source_session.project_id, name=new_session_name
+        ).results
 
         if len(forked_sessions_list) == 0:
             raise click.ClickException("Unable to fork session.")
