@@ -14,9 +14,8 @@ def _validate_credential(token: str) -> None:
     if not token.startswith("sss_"):
         url = anyscale.util.get_endpoint("/credentials")
         raise click.ClickException(
-            f"Malformed credentials: {token}\n"
-            f"Please go to {url} and follow  "
-            "the instructions to properly set the token."
+            "Your user credentials are invalid. Please go to "
+            f"{url} and follow the instructions to properly set your credentials."
         )
 
 
@@ -41,13 +40,18 @@ def load_credentials() -> str:
         except json.JSONDecodeError:
             msg = (
                 "Unable to load user credentials.\n\nTip: Try creating your "
-                "user credentials again by going to {}/credentials and "
+                "user credentials again by going to {} and "
                 "following the instructions. If this does not work, "
-                "please contact Anyscale support!".format(anyscale.conf.ANYSCALE_HOST)
+                "please contact Anyscale support!".format(
+                    anyscale.util.get_endpoint("/credentials")
+                )
             )
             raise click.ClickException(msg)
     received_token = credentials.get("cli_token")
     if received_token is None:
-        raise click.ClickException("Credential file not valid, please regenerate it.")
+        raise click.ClickException(
+            "The credential file is not valid. Please regenerate it by following "
+            "the instructions at {}".format(anyscale.util.get_endpoint("/credentials"))
+        )
     _validate_credential(received_token)
     return received_token
