@@ -8,6 +8,7 @@ import click
 from packaging import version
 
 from anyscale.api import instantiate_api_client
+from anyscale.cli_logger import _CliLogger
 from anyscale.client.openapi_client.rest import ApiException
 from anyscale.commands.anyscale_api.api_commands import anyscale_api
 from anyscale.commands.cloud_commands import cloud_cli
@@ -33,6 +34,8 @@ from anyscale.util import init_sentry
 logger = logging.getLogger(__file__)
 logging.getLogger("botocore").setLevel(logging.CRITICAL)
 
+log = _CliLogger()  # CLI Logger
+
 if anyscale.conf.AWS_PROFILE is not None:
     logger.info("Using AWS profile %s", anyscale.conf.AWS_PROFILE)
     os.environ["AWS_PROFILE"] = anyscale.conf.AWS_PROFILE
@@ -85,7 +88,7 @@ def cli(ctx: Any, version_flag: bool, show_json: bool) -> None:
             message = "Warning: Using version {0} of anyscale. Please update the package using pip install anyscale -U to get the latest version {1}".format(
                 curr_version, latest_version
             )
-            print("\033[91m{}\033[00m".format(message), file=sys.stderr)
+            log.warning(message)
     except ApiException as e:
         logger.warning(
             "Error {} while trying to get latest anyscale version number: {}".format(
@@ -107,7 +110,7 @@ def version_cli(show_json: bool) -> None:
     if show_json:
         print(json.dumps({"version": anyscale.__version__}))
     else:
-        print(anyscale.__version__)
+        log.info(anyscale.__version__)
 
 
 @cli.command(
@@ -115,17 +118,6 @@ def version_cli(show_json: bool) -> None:
 )
 @click.pass_context
 def anyscale_help(ctx: Any) -> None:
-    # TODO: Remove after we no longer want this announcement (in a few weeks).
-    announcement = (
-        "Anyscale now runs on Ray version 1.0.1. Please make sure to have "
-        "this version of Ray installed locally, and in all future sessions "
-        "with Anyscale. Any new sessions started will automatically be started "
-        "with the correct Ray version, but any sessions started before November "
-        " 13, 2020 may need to be restarted or updated with Ray 1.0.1."
-        "You can check your local Ray version with: "
-        "    $ ray --version"
-    )
-    print("\033[32m{}\033[00m".format(announcement), file=sys.stderr)
     print(ctx.parent.get_help())
 
 
