@@ -1,17 +1,13 @@
-import base64
-from contextlib import contextmanager
 import datetime
 import json
 import logging
 import os
-import re
 import subprocess
 import sys
 import threading
 import time
-from typing import Any, cast, Dict, Iterator, List, Optional, Tuple, Type
-import unicodedata
-from urllib.parse import quote as quote_sanitize, urlencode as urlencode, urljoin
+from typing import Any, cast, Dict, Iterator, List, Optional, Tuple
+from urllib.parse import quote as quote_sanitize, urlencode, urljoin
 import webbrowser
 
 import click
@@ -20,24 +16,34 @@ from requests import Response
 import yaml
 
 from anyscale.api import get_api_client
+from anyscale.cli_logger import _CliLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.client.openapi_client.models.user_info import UserInfo
 from anyscale.client.openapi_client.rest import ApiException
 import anyscale.conf
 from anyscale.credentials import load_credentials
+import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
+from anyscale.shared_anyscale_utils.util import get_container_name
 
 
 logger = logging.getLogger(__file__)
 
 BOTO_MAX_RETRIES = 5
 
+log = _CliLogger()  # Anyscale CLI Logger
+
+# Cached 07-21-2021
+_CACHED_GCP_REGIONS = json.loads(
+    open(os.path.join(os.path.dirname(__file__), "cached_gcp_regions.json")).read()
+)["regions"]
+
 
 def confirm(msg: str, yes: bool) -> Any:
     return None if yes else click.confirm(msg, abort=True)
 
 
 def get_endpoint(endpoint: str, host: Optional[str] = None) -> str:
-    return str(urljoin(host or anyscale.conf.ANYSCALE_HOST, endpoint))
+    return str(urljoin(host or shared_anyscale_conf.ANYSCALE_HOST, endpoint))
 
 
 def send_json_request_raw(
@@ -132,44 +138,6 @@ def humanize_timestamp(timestamp: datetime.datetime) -> str:
         return "{} second{} ago".format(delta_s, "s" if delta_s > 1 else "")
 
 
-def execution_log_name(session_command_id: str) -> str:
-    return "/tmp/ray_command_output_{session_command_id}".format(
-        session_command_id=session_command_id
-    )
-
-
-def startup_log_name(session_id: str) -> str:
-    return "/tmp/session_startup_logs_{session_id}".format(session_id=session_id)
-
-
-def startup_log_name_v2(session_id: str, encoded: bool = False) -> str:
-    startup_log_name = "/var/log/anyscale/session_startup_logs_{session_id}".format(
-        session_id=session_id
-    )
-
-    if encoded:
-        # The encoding should be the same as `encodePathToFileName` in go/infra/anyscaled/internal/logcache/utils.go
-        return base64.standard_b64encode(f"{startup_log_name}.out".encode()).decode()
-    else:
-        return startup_log_name
-
-
-def slugify(value: str) -> str:
-    """
-    Code adopted from here https://github.com/django/django/blob/master/django/utils/text.py
-
-    Convert  to ASCII. Convert spaces to hyphens.
-    Remove characters that aren't alphanumerics, underscores, or hyphens.
-    Also strip leading and trailing whitespace.
-    """
-
-    value = (
-        unicodedata.normalize("NFKD", value).encode("ascii", "ignore").decode("ascii")
-    )
-    value = re.sub(r"[^\w\s-]", "", value).strip()
-    return re.sub(r"[-\s]+", "-", value)
-
-
 def get_cluster_config(config_path: str) -> Any:
     with open(config_path) as f:
         cluster_config = yaml.safe_load(f)
@@ -237,13 +205,16 @@ def launch_gcp_cloud_setup(name: str, region: str) -> None:
     query_params = urlencode({"region": region})
     # TODO: Replace this with a proper endpoint
     endpoint = f"/api/v2/clouds/gcp/create/{quote_safe_name}?{query_params}"
-    webbrowser.open(get_endpoint(endpoint))
+    full_url = get_endpoint(endpoint)
+    print(
+        f"Launching GCP Oauth Flow:\n{full_url}\n(If this window does not auto-launch, use the link above)"
+    )
+    webbrowser.open(full_url)
 
 
 class Timer:
     """
     Code adopted from https://stackoverflow.com/a/39504463/3727678
-
     Spawn thread and time process that may be blocking.
     """
 
@@ -304,31 +275,12 @@ def get_active_sessions(
         return response["results"]
 
 
-def get_container_name(cluster_config: Dict[str, Any]) -> str:
-    return str(cluster_config.get("docker", {}).get("container_name", ""))
-
-
-def get_autoscaler_container_path(path: str) -> str:
-    """
-    When autoscaler is run in a separate container, all locations Docker bind-mounted
-    from the host to directory /a/b/c of the user container are instead bind-mounted
-    to /home/ray/autoscaler_mounts/a/b/c in the autoscaler container.
-
-    Args:
-        path: Location in user container.
-    Returns:
-        Location in the autoscaler container.
-    """
-    return f"/home/ray/autoscaler_mounts/{path}"
-
-
 def get_project_directory_name(project_id: str, api_client: DefaultApi = None) -> str:
     if api_client is None:
         api_client = get_api_client()
 
     # TODO (yiran): return error early if project doesn't exist.
-    with format_api_exception(ApiException):
-        resp = api_client.get_project_api_v2_projects_project_id_get(project_id)
+    resp = api_client.get_project_api_v2_projects_project_id_get(project_id)
     directory_name = resp.result.directory_name
     assert len(directory_name) > 0, "Empty directory name found."
     return cast(str, directory_name)
@@ -346,10 +298,49 @@ def get_working_dir(
         return f"/home/ray/{get_project_directory_name(project_id, api_client)}"
 
 
+def get_wheel_url(
+    ray_commit: str,
+    ray_version: str,
+    py_version: Optional[str] = None,
+    sys_platform: Optional[str] = None,
+) -> str:
+    """Return S3 URL for the given release spec or 'latest'."""
+    if py_version is None:
+        py_version = "".join(str(x) for x in sys.version_info[0:2])
+    if sys_platform is None:
+        sys_platform = sys.platform
+
+    if sys_platform == "darwin":
+        if py_version == "38":
+            platform = "macosx_10_13_x86_64"
+        else:
+            platform = "macosx_10_13_intel"
+    elif sys_platform == "win32":
+        platform = "win_amd64"
+    else:
+        platform = "manylinux2014_x86_64"
+
+    if py_version == "38":
+        py_version_malloc = py_version
+    else:
+        py_version_malloc = f"{py_version}m"
+
+    if "dev" in ray_version:
+        ray_release = f"master/{ray_commit}"
+    else:
+        ray_release = f"releases/{ray_version}/{ray_commit}"
+    return (
+        "https://s3-us-west-2.amazonaws.com/ray-wheels/"
+        "{}/ray-{}-cp{}-cp{}-{}.whl".format(
+            ray_release, ray_version, py_version, py_version_malloc, platform
+        )
+    )
+
+
 def wait_for_session_start(
     project_id: str, session_name: str, api_client: Optional[DefaultApi] = None
 ) -> str:
-    print(f"Waiting for session {session_name} to start.")
+    log.info(f"Waiting for cluster {session_name} to start.")
     if api_client is None:
         api_client = get_api_client()
 
@@ -379,7 +370,7 @@ def wait_for_session_start(
                 and session.pending_state is None
             ):
                 raise click.ClickException(
-                    f"Error while starting session {session_name}: Session startup failed due to an error."
+                    f"Error while starting session {session_name}: Session startup failed due to an error ({session.state})."
                 )
             elif (
                 session.state
@@ -405,7 +396,7 @@ def wait_for_head_node_start(
     api_client: Optional[DefaultApi] = None,
 ) -> str:
     url = get_endpoint(f"/projects/{project_id}/sessions/{session_id}")
-    print(
+    log.info(
         f"Waiting for head node of session {session_name} to start. "
         f"Please view the startup logs at {url}"
     )
@@ -437,7 +428,7 @@ def wait_for_head_node_start(
                 )
             elif session.state and "Errored" in session.state:
                 raise click.ClickException(
-                    f"Error while starting session {session_name}: Session startup failed due to an error."
+                    f"Error while starting session {session_name}: Session startup failed due to an error ({session.state})."
                 )
             elif (
                 retry_count >= 2
@@ -459,10 +450,9 @@ def wait_for_head_node_start(
 
 
 def download_anyscale_wheel(api_client: DefaultApi, session_id: str) -> None:
-    with format_api_exception(ApiException):
-        wheel_resp = api_client.session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get(
-            session_id=session_id, _preload_content=False
-        )
+    wheel_resp = api_client.session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get(
+        session_id=session_id, _preload_content=False
+    )
     wheel_path_raw = wheel_resp.headers["content-disposition"]
     assert "filename" in wheel_path_raw, "Error getting anyscale wheel"
     wheel_path = wheel_path_raw.split("filename=")[1].strip('"')
@@ -541,12 +531,16 @@ def get_rsync_command(
     head_ip: str,
     target: str,
     delete: bool,
-    rsync_exclude: List[str] = [],
-    rsync_filter: List[str] = [],
+    rsync_exclude: Optional[List[str]] = None,
+    rsync_filter: Optional[List[str]] = None,
     dry_run: bool = False,
 ) -> Tuple[List[str], Optional[Dict[str, Any]]]:
     rsync_executable = "rsync"
     env = None
+    if rsync_exclude is None:
+        rsync_exclude = []
+    if rsync_filter is None:
+        rsync_filter = []
 
     command_list = [
         rsync_executable,
@@ -581,7 +575,8 @@ def populate_session_args(cluster_config_str: str, config_file_name: str) -> str
     env = jinja2.Environment()
     t = env.parse(cluster_config_str)
     for elem in t.body[0].nodes:
-        if type(elem) == jinja2.nodes.Getattr:  # type: ignore
+
+        if isinstance(elem, jinja2.nodes.Getattr):  # type: ignore
             if elem.attr not in os.environ:
                 prefixed_command = " ".join(
                     [f"{elem.attr}=<value>", "anyscale"] + sys.argv[1:]
@@ -620,23 +615,9 @@ def canonicalize_remote_location(
     return remote_location
 
 
-@contextmanager
-def format_api_exception(exception_type: Type[Exception]) -> Iterator[None]:
-    # This should always be called with exceptions that have a status and reason attribute
-    try:
-        yield
-    except exception_type as e:
-        if isinstance(e, ApiException):
-            raise click.ClickException(f"{e.status}: {str(e)}")
-
-        raise click.ClickException(
-            "{0}: {1}".format(e.status, json.loads(e.body)["error"]["detail"])  # type: ignore
-        )
-
-
 def init_sentry(ctx: click.core.Context) -> None:
     # Only report production and staging errors
-    if anyscale.conf.ANYSCALE_ENV not in ["production", "staging"]:
+    if shared_anyscale_conf.ANYSCALE_ENV not in ["production", "staging"]:
         return
 
     import sentry_sdk
@@ -661,7 +642,7 @@ def init_sentry(ctx: click.core.Context) -> None:
     sentry_sdk.init(
         "https://68d7689b55024e91bb31694539111baa@o565360.ingest.sentry.io/5706818",
         release=get_anyscale_version(),
-        environment=anyscale.conf.ANYSCALE_ENV,
+        environment=shared_anyscale_conf.ANYSCALE_ENV,
     )
 
 
@@ -674,23 +655,31 @@ def get_user_info() -> Optional[UserInfo]:
 
 
 def get_anyscale_version() -> str:
-    # Return git sha if anyscale pip package was built in development mode
-    from pip._internal.operations.freeze import FrozenRequirement
-    import pkg_resources
+    try:
+        # Return git sha if anyscale pip package was built in development mode
+        # TODO (aguo): Pip version 21.2.1 made a change to the FrozenRequirement api. Get rid
+        # of this interal api usage.
+        from pip._internal.operations.freeze import FrozenRequirement
+        import pkg_resources
 
-    distributions = {v.key: v for v in pkg_resources.working_set}
-    distribution = distributions["anyscale"]
-    frozen_requirement = FrozenRequirement.from_dist(distribution)  # type: ignore
-    if frozen_requirement.editable:
-        try:
-            return (
-                subprocess.check_output(  # noqa: B1
-                    ["git", "describe", "--always"],
-                    cwd=os.path.dirname(os.path.realpath(__file__)),
-                )  # noqa: B1
-                .strip()
-                .decode("utf-8")
-            )
-        except subprocess.CalledProcessError:
-            print("Not a git repository, will use standard release versioning")
+        distributions = {v.key: v for v in pkg_resources.working_set}
+        distribution = distributions["anyscale"]
+        frozen_requirement = FrozenRequirement.from_dist(distribution)  # type: ignore
+        if frozen_requirement.editable:
+            try:
+                return (
+                    subprocess.check_output(  # noqa: B1
+                        ["git", "describe", "--always"],
+                        cwd=os.path.dirname(os.path.realpath(__file__)),
+                    )  # noqa: B1
+                    .strip()
+                    .decode("utf-8")
+                )
+            except subprocess.CalledProcessError:
+                log.warning(
+                    "Not a git repository, will use standard release versioning"
+                )
+    except Exception:
+        # None of this is critical behavior and so this should not crash the CLI if we can't get a git version.
+        pass
     return anyscale.__version__
