@@ -1,25 +1,9 @@
 from datetime import datetime, timezone
 import re
-import secrets
 from typing import Any, List, Optional, Tuple
 
-import base62
-
-from anyscale.util import execution_log_name
-
-
-def generate_id() -> str:
-    id_part = base62.encodebytes(secrets.token_bytes(16))
-    return f"{id_part}"
-
-
-def generate_session_command_id() -> str:
-    """
-    generate_session_command_id is a mirror from
-    backend/server/utils/id_gen.py. Consult this
-    source of truth for changes
-    """
-    return f"scd_{generate_id()}"
+from anyscale.shared_anyscale_utils.util import execution_log_name
+from anyscale.shared_anyscale_utils.utils.id_gen import generate_id, IDTypes
 
 
 # *_DELIMITER are used within preexec / precmd zsh hooks to so that
@@ -181,7 +165,7 @@ def extract_commands(
             command = Command(
                 term_name=term_name,
                 command=cmd_text,
-                scid=generate_session_command_id(),
+                scid=generate_id(IDTypes.session_commands),
             )
             commands.append(command)
         elif RET_STATUS_MATCH_TEXT in val:
