@@ -68,6 +68,21 @@ def test_setup_cloud_gcp(mock_api_client: Mock) -> None:
         )
 
 
+def test_setup_cloud_gcp_bad_region(mock_api_client: Mock) -> None:
+    mock_confirm = Mock(side_effect=ClickException("aborted"))
+    with patch.multiple(
+        "anyscale.controllers.cloud_controller", confirm=mock_confirm,
+    ):
+        cloud_controller = CloudController(api_client=mock_api_client)
+        # NOTE: GCP regions are [cont]-[local][number], not [cont]-[local]-[number]
+        with pytest.raises(ClickException):
+            cloud_controller.setup_cloud(
+                provider="gcp", region="us-west-2", name="test-gcp"
+            )
+
+        mock_confirm.assert_called()
+
+
 def test_setup_cloud_invalid_provider(mock_api_client: Mock) -> None:
     cloud_controller = CloudController(api_client=mock_api_client)
     with pytest.raises(ClickException):
