@@ -262,7 +262,7 @@ def test_list_ips_table(session_test_data: Session, mock_api_client: Mock) -> No
     mock_get_project_id.assert_called_once_with(mock_project_definition.root)
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
         project_id=session_test_data.project_id,
-        name_match=None,
+        name=None,
         state_filter=["AwaitingFileMounts", "Running"],
         _request_timeout=ANY,
     )
@@ -321,7 +321,7 @@ def test_list_ips_json(
     # TODO (jbai): code can be optimized, this api request is issued multiple times
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_with(
         project_id=session_test_data.project_id,
-        name_match=session_test_data.name,
+        name=session_test_data.name,
         state_filter=["AwaitingFileMounts", "Running"],
         _request_timeout=ANY,
     )
