@@ -40,20 +40,18 @@ def test_clone_project(
     project_controller._write_sample_compute_config = Mock()  # type: ignore
 
     os_makedirs_mock = Mock(return_value=None)
+    mock_write_project_file_to_disk = Mock(return_value=None)
     with patch.multiple("os", makedirs=os_makedirs_mock), patch(
-        "anyscale.project._write_cluster_config_to_disk"
-    ) as write_cluster_config_mock:
+        "anyscale.controllers.project_controller._write_project_file_to_disk"
+    ) as mock_write_project_file_to_disk:
         project_controller.clone(project_name=project_test_data.name, owner=owner)
 
     mock_api_client.find_project_by_project_name_api_v2_projects_find_by_name_get.assert_called_once_with(
         name=project_test_data.name, _request_timeout=ANY, owner=owner
     )
-    mock_api_client.get_project_latest_cluster_config_api_v2_projects_project_id_latest_cluster_config_get.assert_called_once_with(
-        project_test_data.id,
-    )
     os_makedirs_mock.assert_called_once_with(project_test_data.name)
-    write_cluster_config_mock.assert_called_once_with(
-        project_test_data.id, "", project_test_data.name
+    mock_write_project_file_to_disk.assert_called_once_with(
+        project_test_data.id, project_test_data.name
     )
 
     project_controller._write_sample_compute_config.assert_called_once_with(
@@ -62,10 +60,7 @@ def test_clone_project(
     )
 
 
-@pytest.mark.parametrize("config", [None, "tmp.yaml"])
-def test_init_project(
-    project_test_data: Project, mock_api_client: Mock, config: str
-) -> None:
+def test_init_project(project_test_data: Project, mock_api_client: Mock) -> None:
     project_controller = ProjectController(
         api_client=mock_api_client, anyscale_client=Mock()
     )
@@ -76,29 +71,20 @@ def test_init_project(
         return_value=(project_test_data.name, project_definition)
     )
     mock_register_project = Mock()
-    mock_validate_cluster_configuration = Mock()
+    os_path_exists_mock = Mock(return_value=False)
 
     with patch.multiple(
         "anyscale.controllers.project_controller",
         create_new_proj_def=mock_create_new_proj_def,
         register_project=mock_register_project,
-        validate_cluster_configuration=mock_validate_cluster_configuration,
-    ):
-        project_controller.init(name=project_test_data.name, config=config)
+    ), patch.multiple("os.path", exists=os_path_exists_mock):
+        project_controller.init(name=project_test_data.name)
 
     mock_create_new_proj_def.assert_called_once_with(
-        project_test_data.name,
-        config,
-        api_client=mock_api_client,
-        use_default_yaml=(not bool(config)),
+        project_test_data.name, api_client=mock_api_client,
     )
     mock_register_project.assert_called_once_with(project_definition, mock_api_client)
 
-    if config:
-        mock_validate_cluster_configuration.assert_called_once_with(
-            config, api_instance=mock_api_client
-        )
-
     project_controller._write_sample_compute_config.assert_called_once_with(
         COMPUTE_CONFIG_FILENAME,
     )
