@@ -31,12 +31,12 @@ from anyscale.client.openapi_client import (
     StopSessionOptions,
 )
 from anyscale.controllers.session_controller import SessionController
-from anyscale.project import CLUSTER_YAML_TEMPLATE
 from anyscale.sdk.anyscale_client import (
     CreateSession,
     StartSessionOptions,
     UpdateSession,
 )
+from anyscale.shared_anyscale_utils.project import CLUSTER_YAML_TEMPLATE
 
 
 COMPUTE_CONFIG_TEMPLATE = json.dumps(
@@ -242,12 +242,7 @@ def test_anyscale_up_success(
     mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
     base_mock_anyscale_api_client: Mock,
 ) -> None:
-    (
-        mock_api_client,
-        project_test_data,
-        cloud_test_data,
-        mock_wait_for_start,
-    ) = mock_up_tuple
+    (mock_api_client, project_test_data, cloud_test_data, _,) = mock_up_tuple
     session_controller = SessionController(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
     )
@@ -315,12 +310,7 @@ def test_anyscale_up_failure(
     mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
     base_mock_anyscale_api_client: Mock,
 ) -> None:
-    (
-        mock_api_client,
-        project_test_data,
-        cloud_test_data,
-        mock_wait_for_start,
-    ) = mock_up_tuple
+    (mock_api_client, _, _, mock_wait_for_start,) = mock_up_tuple
     session_controller = SessionController(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
     )
@@ -366,12 +356,7 @@ def test_anyscale_up_no_config_provided(
     mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
     base_mock_anyscale_api_client: Mock,
 ) -> None:
-    (
-        mock_api_client,
-        project_test_data,
-        cloud_test_data,
-        mock_wait_for_start,
-    ) = mock_up_tuple
+    (mock_api_client, project_test_data, cloud_test_data, _,) = mock_up_tuple
     session_controller = SessionController(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
     )
@@ -442,12 +427,7 @@ def test_anyscale_app_template(
     mock_up_tuple: Tuple[Mock, Project, Cloud, Mock],
     base_mock_anyscale_api_client: Mock,
 ) -> None:
-    (
-        mock_api_client,
-        project_test_data,
-        cloud_test_data,
-        mock_wait_for_start,
-    ) = mock_up_tuple
+    (mock_api_client, project_test_data, cloud_test_data, _,) = mock_up_tuple
     session_controller = SessionController(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
     )
@@ -614,9 +594,9 @@ def test_list_app_configs(
     session_controller = SessionController(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
     )
-    session_controller._list_app_configs(project_test_data.id)
+    session_controller._list_app_configs(project_id=project_test_data.id)
     base_mock_anyscale_api_client.list_app_configs.assert_called_once_with(
-        project_test_data.id, count=50, paging_token=None
+        project_id=project_test_data.id, count=50, paging_token=None
     )
 
 
@@ -651,6 +631,7 @@ def test_get_app_config_id_from_name(
                 name="mock_app_config_name",
                 id="mock_app_config_id",
                 project_id=project_test_data.id,
+                organization_id="org_1",
                 creator_id=ANY,
                 created_at=ANY,
                 last_modified_at=ANY,
@@ -724,7 +705,7 @@ def test_anyscale_start(
     sync_files: bool,
     use_build_id: bool,
 ) -> None:
-    (mock_api_client, project_test_data, _, mock_wait_for_start,) = mock_up_tuple
+    (mock_api_client, project_test_data, _, _,) = mock_up_tuple
     session_controller = SessionController(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client
     )
