@@ -1,15 +1,25 @@
+# type: ignore
+
+import copy
 import os
 from pathlib import Path
 import random
+import shutil
+import subprocess
+import sys
 import tempfile
-from typing import Any, AsyncGenerator, Generator, Optional, Set, Tuple
+from typing import Any, AsyncGenerator, Dict, Generator, Optional, Set, Tuple
+from unittest.mock import Mock
 
 import pytest
 import ray
 
 import anyscale
+from anyscale.utils.ray_conda import get_conda_activate_commands
 from anyscale.utils.runtime_env import (
     _calc_pkg_for_working_dir,
+    _get_conda_dict,
+    _get_conda_env_path,
     _read_dir_meta,
     ensure_runtime_env_setup,
     rewrite_runtime_env_uris,
@@ -23,8 +33,7 @@ def random_working_dir() -> Generator[Tuple[Path, Set[Path], Set[Path]], None, N
     We'll use this working_dir to test uploading/downloading
     """
     anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL = 256 * 1024  # 256kb
-    anyscale.utils.runtime_env.KEY_PREFIX = "org_id_"
-    anyscale.utils.runtime_env.S3BUCKET = "test"
+    os.environ["ANYSCALE_DEBUG"] = "1"
     with tempfile.TemporaryDirectory() as tmp_dir:
         item_num = 0
         root = Path(tmp_dir) / "test"
@@ -47,13 +56,13 @@ def random_working_dir() -> Generator[Tuple[Path, Set[Path], Set[Path]], None, N
             path.mkdir(parents=True, exist_ok=True)
             dir_num = random.randint(0, 5)
             file_num = random.randint(0, 5)
-            # cover empty dir
+            if path != root:
+                small_files.add(path.relative_to(root))
             if (
                 depth > 8
                 or item_num > 1000
                 or (dir_num == 0 and file_num == 0 and depth != 0)
             ):
-                small_files.add(path.relative_to(root))
                 return
             for _ in range(dir_num):
                 tmp_dir = tempfile.mkdtemp(dir=path)
@@ -79,6 +88,62 @@ def random_working_dir() -> Generator[Tuple[Path, Set[Path], Set[Path]], None, N
         yield (root, big_files, small_files)
 
 
+def test_get_conda_dict() -> None:
+    """This test is to check whether anyscale/ray[default]/python version
+    got injected correctly in anyscale product code path.
+    """
+    with tempfile.TemporaryDirectory() as tmp_dir:
+        with open("requirements.txt", "w") as t:
+            t.write(
+                """pip-install-test==0.5
+ray"""
+            )
+        import ray.workers.setup_runtime_env
+
+        current_ray_pip_specifier = Mock()
+        current_ray_pip_specifier.return_value = "ray==test"
+        ray.workers.setup_runtime_env.current_ray_pip_specifier = (
+            current_ray_pip_specifier
+        )
+        py_version = ".".join(map(str, sys.version_info[:3]))
+        test_wheel = "ANYSCALE_TEST_WHEEL_ADDR"
+        # With this flag on, it'll use user wheel for anyscale
+        # this is useful for testing
+        os.environ["ANYSCALE_USER_WHEEL"] = test_wheel
+        pip_txt = "test1\test2"
+        runtime_env = {
+            "working_dir": ".",
+            "pip": pip_txt,
+        }
+
+        conda_dict = _get_conda_dict(runtime_env, tmp_dir)
+        deps = conda_dict["dependencies"]
+        assert deps[0] == "pip"
+        # anyscale is always put at the beginning
+        pips = deps[1]["pip"]
+        assert len(pips) == 4
+        pips[3] = Path(pips[3].split()[1]).read_text()
+        assert pips == [test_wheel, "ray==test", "ray[default]", pip_txt]
+        assert deps[2] == f"python={py_version}"
+
+        # Test the case when it's off and use anyscale.__version__
+        # automatically
+        os.environ.pop("ANYSCALE_USER_WHEEL")
+        conda_dict = _get_conda_dict(runtime_env, tmp_dir)
+        deps = conda_dict["dependencies"]
+        assert deps[0] == "pip"
+        pips = deps[1]["pip"]
+        assert len(pips) == 4
+        pips[3] = Path(pips[3].split()[1]).read_text()
+        assert pips == [
+            f"anyscale=={anyscale.__version__}",
+            "ray==test",
+            "ray[default]",
+            pip_txt,
+        ]
+        assert deps[2] == f"python={py_version}"
+
+
 def test_split_no_base(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) -> None:
     # Test splitting when there is no base dir
     (working_dir, big_files, small_files) = random_working_dir
@@ -96,7 +161,6 @@ def test_split_no_base(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) ->
     assert del_pkg is None
     assert add_pkg is None
     assert base_pkg is not None
-
     files = {u[0] for u in base_pkg._contents}
     assert files == small_files
 
@@ -125,9 +189,7 @@ def test_split_with_base_del(
     # Try to split the working dir without base
     (working_dir, big_files, small_files_set) = random_working_dir
     _calc_pkg_for_working_dir(working_dir, [], None)
-    (base_pkg, add_pkg, del_pkg, file_pkgs) = _calc_pkg_for_working_dir(
-        working_dir, [], None
-    )
+    (base_pkg, _, _, file_pkgs) = _calc_pkg_for_working_dir(working_dir, [], None)
     assert base_pkg is not None
     # Update the base
     base_pkg.update_meta()
@@ -145,9 +207,14 @@ def test_split_with_base_del(
     assert file_pkgs == new_file_pkgs
     small_files = list(small_files_set)
     random.shuffle(small_files)
-
+    del_small_file = None
+    for small_file in small_files:
+        p = working_dir / small_file
+        if not p.is_dir() or next(p.iterdir(), None) is None:
+            del_small_file = small_file
+            break
+    small_files.remove(del_small_file)
     # Now delete a small file
-    del_small_file = small_files.pop()
     p = working_dir / del_small_file
     del_bytes = 0
     if p.is_dir():
@@ -171,11 +238,9 @@ def test_split_with_base_update(
 ) -> None:
     # We now test the split for base update cases
     anyscale.utils.runtime_env.DELTA_PKG_LIMIT = 1024 * 1024  # 1mb
-    (working_dir, big_files, small_files_set) = random_working_dir
+    (working_dir, _, small_files_set) = random_working_dir
     _calc_pkg_for_working_dir(working_dir, [], None)
-    (base_pkg, add_pkg, del_pkg, file_pkgs) = _calc_pkg_for_working_dir(
-        working_dir, [], None
-    )
+    (base_pkg, _, _, file_pkgs) = _calc_pkg_for_working_dir(working_dir, [], None)
     assert base_pkg is not None
     base_pkg.update_meta()
 
@@ -223,7 +288,7 @@ def test_split_with_base_update(
 def test_split_with_all_big_files() -> None:
     anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL = 256 * 1024  # 256kb
     with tempfile.TemporaryDirectory() as tmp_dir:
-        for i in range(10):
+        for _ in range(10):
             with tempfile.NamedTemporaryFile(dir=tmp_dir, delete=False) as f:
                 f.write(b"A" * (anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL + 1))
         (
@@ -255,48 +320,100 @@ def dir_hash(path: Optional[str]) -> int:
             s += sum(curr_path.read_bytes())
             s += sum(str(curr_path.relative_to(Path(path))).encode())
         for d in dirs:
-            curr_path = Path(root) / f
+            curr_path = Path(root) / d
             s += sum(str(curr_path.relative_to(Path(path))).encode())
     return s
 
 
+class MockS3Meta:
+    db: Dict[str, Any] = {}
+    put_cnt: int = 0
+    get_cnt: int = 0
+
+
+def mock_setup_s3_related_funcs() -> MockS3Meta:
+    meta = MockS3Meta()
+
+    async def _object_exists(s3: Any, bucket: str, key: str) -> bool:
+        nonlocal meta
+        return key in meta.db
+
+    async def _put_object(s3: Any, bucket: str, key: str, p: str) -> None:
+        nonlocal meta
+        meta.put_cnt += 1
+        meta.db[key] = Path(p).read_bytes()
+
+    class StreamBody:
+        def __init__(self, data: bytes):
+            self._data = data
+
+        async def iter_chunks(self) -> AsyncGenerator[bytes, None]:
+            n = 64
+            for i in range(0, len(self._data), n):
+                yield self._data[i : i + n]
+
+    async def _get_object(s3: Any, bucket: str, key: str) -> StreamBody:
+        nonlocal meta
+        meta.get_cnt += 1
+        return StreamBody(meta.db.get(key, b""))
+
+    def _gen_token() -> Any:
+        class Token:
+            def __init__(self) -> None:
+                self.region = "west"
+                self.aws_access_key_id = ""
+                self.aws_secret_access_key = ""
+                self.aws_session_token = ""
+                self.bucket = "test"
+                self.path = "/"
+
+        return Token()
+
+    # Inject s3 related functions
+    anyscale.utils.runtime_env._object_exists = _object_exists
+    anyscale.utils.runtime_env._put_object = _put_object
+    anyscale.utils.runtime_env._get_object = _get_object
+    anyscale.utils.runtime_env._gen_token = _gen_token
+    return meta
+
+
+def test_split_with_base_del_2() -> None:
+    with tempfile.TemporaryDirectory() as d:
+        pkg_dir = Path(d) / "pkg_dir"
+        pkg_dir.mkdir()
+        working_dir = Path(d) / "working_dir"
+        working_dir.mkdir()
+
+        (working_dir / "sub").mkdir()
+        (working_dir / "sub" / "text").write_text("a" * 128)
+        (working_dir / "sub2").mkdir()
+        (working_dir / "sub2" / "text").write_text("a" * 128)
+
+        _calc_pkg_for_working_dir(working_dir, [], None)
+        base_pkg = _calc_pkg_for_working_dir(working_dir, [], None)[0]
+        assert base_pkg is not None
+        # Update the base
+        base_pkg.update_meta()
+        (working_dir / "sub" / "text").unlink()
+        (working_dir / "sub2" / "text").unlink()
+        (working_dir / "sub2").rmdir()
+
+        (_, new_add_pkg, new_del_pkg, new_file_pkgs,) = _calc_pkg_for_working_dir(
+            working_dir, [], _read_dir_meta(working_dir, True)
+        )
+
+        assert new_add_pkg is None
+        assert len(new_file_pkgs) == 0
+        assert new_del_pkg is not None
+        assert len(new_del_pkg._contents) == 2
+        assert {str(c[0]) for c in new_del_pkg._contents} == {"sub/text", "sub2"}
+
+
 def test_e2e(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) -> None:
     with tempfile.TemporaryDirectory() as d:
-        ray._private.runtime_env.PKG_DIR = d
-        db = {}
-        put_cnt = 0
-        get_cnt = 0
-
-        async def _object_exists(s3: Any, key: str) -> bool:
-            nonlocal db
-            return key in db
-
-        async def _put_object(s3: Any, key: str, p: str) -> None:
-            nonlocal db
-            nonlocal put_cnt
-            put_cnt += 1
-            db[key] = Path(p).read_bytes()
-
-        class StreamBody:
-            def __init__(self, data: bytes):
-                self._data = data
-
-            async def iter_chunks(self) -> AsyncGenerator[bytes, None]:
-                n = 64
-                for i in range(0, len(self._data), n):
-                    yield self._data[i : i + n]
-
-        async def _get_object(s3: Any, key: str) -> StreamBody:
-            nonlocal db
-            nonlocal get_cnt
-            get_cnt += 1
-            return StreamBody(db.get(key, b""))
-
+        anyscale.utils.runtime_env.PKG_DIR = d
+        meta = mock_setup_s3_related_funcs()
         (working_dir, big_files, small_files_set) = random_working_dir
-        # Inject s3 related functions
-        anyscale.utils.runtime_env._object_exists = _object_exists
-        anyscale.utils.runtime_env._put_object = _put_object  # type: ignore
-        anyscale.utils.runtime_env._get_object = _get_object
 
         def run(working_dir: str = str(working_dir)) -> Optional[str]:
             job_config = ray.job_config.JobConfig(
@@ -309,16 +426,16 @@ def test_e2e(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) -> None:
             return ensure_runtime_env_setup(uris)
 
         assert dir_hash(str(working_dir)) == dir_hash(run())
-        old_put_cnt, old_get_cnt = put_cnt, get_cnt
+        old_put_cnt, old_get_cnt = meta.put_cnt, meta.get_cnt
         assert dir_hash(str(working_dir)) == dir_hash(run())
-        assert old_put_cnt == put_cnt
-        assert old_get_cnt == get_cnt
+        assert old_put_cnt == meta.put_cnt
+        assert old_get_cnt == meta.get_cnt
 
         del_big_file = random.choice(list(big_files))
         (working_dir / del_big_file).unlink()
         assert dir_hash(str(working_dir)) == dir_hash(run())
-        assert old_put_cnt == put_cnt
-        assert old_get_cnt == get_cnt
+        assert old_put_cnt == meta.put_cnt
+        assert old_get_cnt == meta.get_cnt
 
         small_files = list(small_files_set)
         random.shuffle(small_files)
@@ -333,8 +450,8 @@ def test_e2e(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) -> None:
             updated_bytes += p.stat().st_size
             break
         assert dir_hash(str(working_dir)) == dir_hash(run())
-        assert old_put_cnt + 1 == put_cnt
-        assert old_get_cnt + 1 == get_cnt
+        assert old_put_cnt + 1 == meta.put_cnt
+        assert old_get_cnt + 1 == meta.get_cnt
 
         # update a lot small files to trigger updating base
         anyscale.utils.runtime_env.DELTA_PKG_LIMIT = 1024 * 1024  # 1mb
@@ -346,35 +463,106 @@ def test_e2e(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) -> None:
             with p.open("wb") as f:
                 f.write(val)
             updated_bytes += p.stat().st_size
-        old_put_cnt, old_get_cnt = put_cnt, get_cnt
+        old_put_cnt, old_get_cnt = meta.put_cnt, meta.get_cnt
         assert dir_hash(str(working_dir)) == dir_hash(run())
-        assert old_get_cnt + 1 == get_cnt
-        assert old_put_cnt + 1 == put_cnt
+        assert old_get_cnt + 1 == meta.get_cnt
+        assert old_put_cnt + 1 == meta.put_cnt
 
         # now add some files
         with tempfile.NamedTemporaryFile(dir=working_dir, delete=False) as f1:
             f1.write(b"A" * (anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL - 1))
         with tempfile.NamedTemporaryFile(dir=working_dir, delete=False) as f2:
             f2.write(b"A" * (anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL + 1))
-        old_put_cnt, old_get_cnt = put_cnt, get_cnt
+        old_put_cnt, old_get_cnt = meta.put_cnt, meta.get_cnt
         assert dir_hash(str(working_dir)) == dir_hash(run())
-        assert old_get_cnt + 2 == get_cnt
-        assert old_put_cnt + 2 == put_cnt
+        assert old_get_cnt + 2 == meta.get_cnt
+        assert old_put_cnt + 2 == meta.put_cnt
 
         # Now create a new dir with all big files
         with tempfile.TemporaryDirectory() as big_tmp:
-            for i in range(10):
-                with tempfile.NamedTemporaryFile(dir=big_tmp, delete=False) as f:  # type: ignore
+            for _ in range(10):
+                with tempfile.NamedTemporaryFile(dir=big_tmp, delete=False) as f:
                     f.write(b"A" * (anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL + 1))
             assert dir_hash(big_tmp) == dir_hash(run(big_tmp))
 
         # Now create a new dir with all small files
         with tempfile.TemporaryDirectory() as big_tmp:
-            for i in range(10):
-                with tempfile.NamedTemporaryFile(dir=big_tmp, delete=False) as f:  # type: ignore
+            for _ in range(10):
+                with tempfile.NamedTemporaryFile(dir=big_tmp, delete=False) as f:
                     f.write(b"A" * (anyscale.utils.runtime_env.SINGLE_FILE_MINIMAL - 1))
             assert dir_hash(big_tmp) == dir_hash(run(big_tmp))
 
         # Now create a new dir with no files
         with tempfile.TemporaryDirectory() as big_tmp:
             assert dir_hash(big_tmp) == dir_hash(run(big_tmp))
+
+
+@pytest.mark.skipif(True, reason="Need pinned ray updates to test it")
+@pytest.mark.parametrize("env_type", ["pip", "conda"])
+def test_client_setver_env_prep_e2e(env_type: str) -> None:
+    with tempfile.TemporaryDirectory() as d:
+        anyscale.utils.runtime_env.PKG_DIR = d
+        assert _get_conda_env_path({"conda": "test_env"}, d) == "test_env"
+        from anyscale.connect import REQUIRED_RAY_COMMIT
+
+        ray_release = "master/" + REQUIRED_RAY_COMMIT
+        if env_type == "conda":
+            input_runtime_env = {
+                "conda": {
+                    "dependencies": [
+                        "pip",
+                        {
+                            "pip": [
+                                "pip-install-test==0.5",
+                                "opentelemetry-api==1.1.0",
+                                "opentelemetry-sdk==1.1.0",
+                            ]
+                        },
+                    ]
+                },
+                "_ray_release": ray_release,
+            }
+        else:
+            input_runtime_env = {
+                "pip": """pip-install-test==0.5
+opentelemetry-api==1.1.0
+opentelemetry-sdk==1.1.0""",
+                "_ray_release": ray_release,
+            }
+
+        meta = mock_setup_s3_related_funcs()
+
+        # conda pkg created
+        with pytest.raises(ModuleNotFoundError):
+            # Ensure pip-install-test is not installed on the test machine
+            import pip_install_test  # noqa
+        conda_path = _get_conda_env_path(copy.deepcopy(input_runtime_env), d)
+        assert conda_path is not None
+        cmds = get_conda_activate_commands(conda_path)
+        cmds.append("python -c 'import pip_install_test; print(0)'")
+        out = subprocess.run(  # noqa: B1
+            " && ".join(cmds),
+            shell=True,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        ).stdout
+        assert out.split()[-1] == b"0"
+
+        old_get_cnt, old_put_cnt = meta.get_cnt, meta.put_cnt
+        # Re-run it and it'll skip downloading
+        conda_path = _get_conda_env_path(copy.deepcopy(input_runtime_env), d)
+        assert old_get_cnt == meta.get_cnt
+        assert old_put_cnt == meta.put_cnt
+        # Delete it and set it up from caching
+        shutil.rmtree(conda_path)
+        old_get_cnt, old_put_cnt = meta.get_cnt, meta.put_cnt
+        conda_path = _get_conda_env_path(copy.deepcopy(input_runtime_env), d)
+        assert old_put_cnt == meta.put_cnt
+        assert old_get_cnt + 1 == meta.get_cnt
+        out = subprocess.run(  # noqa: B1
+            " && ".join(cmds),
+            shell=True,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        ).stdout
+        assert out.split()[-1] == b"0"
